==> nui_error_handler-0.0.1.tar.gz: lib/nui_error_models.dart <==
import 'package:nui_core/data/nui_ent.dart';
import 'package:nui_core/string/nui_string_util.dart';
import 'package:nui_database/models/nui_database_entity.dart';
import 'package:nui_database/models/nui_database_entity_field.dart';
import 'package:nui_database/models/nui_database_entity_mapper.dart';

class NUIErrorMapping extends NUIDBEntity<NUIErrorMapping>{
  NUIErrorMapping.empty();
  NUIErrorMapping({this.code, this.title, this.message, this.actionMessage, this.actionCode, this.actionType, this.extra});
  String code;
  String title;
  String message;
  String actionType;
  String actionCode;
  String actionMessage;
  String extra;

  @override
  NUIEntMapper<NUIErrorMapping> mapper() => NUIErrorMappingEntity();
}

class NUIErrorMappingEntity extends NUIDBEntityMapper<NUIErrorMapping>{
  @override
  List<NUIDBField> dbFields() {
    return [
      NUIDBField<NUIErrorMapping>(name: "code", type: NUIEntType.STRING, setter: (data, value) => data.code = value, getter: (data) => data.code, primaryKey: true),
      NUIDBField<NUIErrorMapping>(name: "title", type: NUIEntType.STRING, setter: (data, value) => data.title = value, getter: (data) => data.title),
      NUIDBField<NUIErrorMapping>(name: "message", type: NUIEntType.STRING, setter: (data, value) => data.message = value, getter: (data) => data.message),
      NUIDBField<NUIErrorMapping>(name: "actionType", type: NUIEntType.STRING, setter: (data, value) => data.actionType = value, getter: (data) => data.actionType),
      NUIDBField<NUIErrorMapping>(name: "actionCode", type: NUIEntType.STRING, setter: (data, value) => data.actionCode = value, getter: (data) => data.actionCode),
      NUIDBField<NUIErrorMapping>(name: "actionMessage", type: NUIEntType.STRING, setter: (data, value) => data.actionMessage = value, getter: (data) => data.actionMessage),
      NUIDBField<NUIErrorMapping>(name: "extra", type: NUIEntType.STRING, setter: (data, value) => data.extra = value, getter: (data) => data.extra),
    ];
  }

  @override
  String entityName() => "NUIErrorMapping";

  @override
  NUIErrorMapping newInstance() => NUIErrorMapping.empty();
}

class NUIErrorLog extends NUIDBEntity<NUIErrorLog>{
  NUIErrorLog.empty();
  NUIErrorLog({this.id, this.screenCode, this.type, this.title, this.description, this.appVersion, this.dateTime, this.module, this.code, this.platform, this.model});
  String id = randomUUID(); //Unique ID for each error log
  String screenCode; //Code for each screen
  String type; //Error type
  String platform; //iOS, Android
  String model; //Phone model (iPhone 11 Pro, Samsung Galaxy Note 10)
  String code; //Model code (SM N970F)
  String title; //Title of the exception, eg NullPointerException
  String description; //Description of the error
  String appVersion; //App version, based on the version of the project itself
  DateTime dateTime; //Date and time of the crash
  String module; //Module of the of NUIErrorHandler specified during builder

  @override
  NUIEntMapper<NUIErrorLog> mapper() => NUIErrorLogEntity();
}

class NUIErrorLogEntity extends NUIDBEntityMapper<NUIErrorLog>{
  @override
  List<NUIDBField> dbFields() {
    return [
      NUIDBField<NUIErrorLog>(name: "id", type: NUIEntType.STRING, setter: (data, value) => data.id = value, getter: (data) => data.id, primaryKey: true),
      NUIDBField<NUIErrorLog>(name: "screenCode", type: NUIEntType.STRING, setter: (data, value) => data.screenCode = value, getter: (data) => data.screenCode),
      NUIDBField<NUIErrorLog>(name: "type", type: NUIEntType.STRING, setter: (data, value) => data.type = value, getter: (data) => data.type),
      NUIDBField<NUIErrorLog>(name: "platform", type: NUIEntType.STRING, setter: (data, value) => data.platform = value, getter: (data) => data.platform),
      NUIDBField<NUIErrorLog>(name: "model", type: NUIEntType.STRING, setter: (data, value) => data.model = value, getter: (data) => data.model),
      NUIDBField<NUIErrorLog>(name: "code", type: NUIEntType.STRING, setter: (data, value) => data.code = value, getter: (data) => data.code),
      NUIDBField<NUIErrorLog>(name: "title", type: NUIEntType.STRING, setter: (data, value) => data.title = value, getter: (data) => data.title),
      NUIDBField<NUIErrorLog>(name: "description", type: NUIEntType.STRING, setter: (data, value) => data.description = value, getter: (data) => data.description),
      NUIDBField<NUIErrorLog>(name: "appVersion", type: NUIEntType.STRING, setter: (data, value) => data.appVersion = value, getter: (data) => data.appVersion),
      NUIDBField<NUIErrorLog>(name: "dateTime", type: NUIEntType.DATE, setter: (data, value) => data.dateTime = asDateTime(value), getter: (data) => data.dateTime),
      NUIDBField<NUIErrorLog>(name: "module", type: NUIEntType.STRING, setter: (data, value) => data.module = value, getter: (data) => data.module),
    ];
  }

  @override
  String entityName() => "NUIErrorLogEntity";

  @override
  NUIErrorLog newInstance() => NUIErrorLog.empty();
}

==> nui_error_handler-0.0.2.tar.gz: lib/nui_error_models.dart <==
import 'package:nui_core/data/nui_ent.dart';
import 'package:nui_core/string/nui_string_util.dart';
import 'package:nui_database/models/nui_database_entity.dart';
import 'package:nui_database/models/nui_database_entity_field.dart';
import 'package:nui_database/models/nui_database_entity_mapper.dart';

class NUIErrorMapping extends NUIDBEntity<NUIErrorMapping>{
  NUIErrorMapping.empty();
  NUIErrorMapping({this.code, this.module, this.title, this.message, this.actionMessage, this.actionCode, this.actionType, this.extra});
  String id;
  String code;
  String module;
  String title;
  String message;
  String actionType;
  String actionCode;
  String actionMessage;
  String extra;

  @override
  NUIEntMapper<NUIErrorMapping> mapper() => NUIErrorMappingEntity();
}

class NUIErrorMappingEntity extends NUIDBEntityMapper<NUIErrorMapping>{
  @override
  List<NUIDBField> dbFields() {
    return [
      NUIDBField<NUIErrorMapping>(name: "code", type: NUIEntType.STRING, setter: (data, value) => data.code = value, getter: (data) => data.code),
      NUIDBField<NUIErrorMapping>(name: "module", type: NUIEntType.STRING, setter: (data, value) => data.module = value, getter: (data) => data.module),
      NUIDBField<NUIErrorMapping>(name: "title", type: NUIEntType.STRING, setter: (data, value) => data.title = value, getter: (data) => data.title),
      NUIDBField<NUIErrorMapping>(name: "message", type: NUIEntType.STRING, setter: (data, value) => data.message = value, getter: (data) => data.message),
      NUIDBField<NUIErrorMapping>(name: "actionType", type: NUIEntType.STRING, setter: (data, value) => data.actionType = value, getter: (data) => data.actionType),
      NUIDBField<NUIErrorMapping>(name: "actionCode", type: NUIEntType.STRING, setter: (data, value) => data.actionCode = value, getter: (data) => data.actionCode),
      NUIDBField<NUIErrorMapping>(name: "actionMessage", type: NUIEntType.STRING, setter: (data, value) => data.actionMessage = value, getter: (data) => data.actionMessage),
      NUIDBField<NUIErrorMapping>(name: "extra", type: NUIEntType.STRING, setter: (data, value) => data.extra = value, getter: (data) => data.extra),
      NUIDBField<NUIErrorMapping>(name: "id", type: NUIEntType.STRING, setter: (data, value) => data.id = data.code + "-" + data.module, getter: (data) => data.code + "-" + data.module, primaryKey: true),
    ];
  }

  @override
  String entityName() => "NUIErrorMapping";

  @override
  NUIErrorMapping newInstance() => NUIErrorMapping.empty();
}

class NUIErrorLog extends NUIDBEntity<NUIErrorLog>{
  NUIErrorLog.empty();
  NUIErrorLog({this.id, this.screenCode, this.type, this.title, this.description, this.appVersion, this.dateTime, this.module, this.code, this.platform, this.model});
  String id = randomUUID(); //Unique ID for each error log
  String screenCode; //Code for each screen
  String type; //Error type
  String platform; //iOS, Android
  String model; //Phone model (iPhone 11 Pro, Samsung Galaxy Note 10)
  String code; //Model code (SM N970F)
  String title; //Title of the exception, eg NullPointerException
  String description; //Description of the error
  String appVersion; //App version, based on the version of the project itself
  DateTime dateTime; //Date and time of the crash
  String module; //Module of the of NUIErrorHandler specified during builder

  @override
  NUIEntMapper<NUIErrorLog> mapper() => NUIErrorLogEntity();
}

class NUIErrorLogEntity extends NUIDBEntityMapper<NUIErrorLog>{
  @override
  List<NUIDBField> dbFields() {
    return [
      NUIDBField<NUIErrorLog>(name: "id", type: NUIEntType.STRING, setter: (data, value) => data.id = value, getter: (data) => data.id, primaryKey: true),
      NUIDBField<NUIErrorLog>(name: "screenCode", type: NUIEntType.STRING, setter: (data, value) => data.screenCode = value, getter: (data) => data.screenCode),
      NUIDBField<NUIErrorLog>(name: "type", type: NUIEntType.STRING, setter: (data, value) => data.type = value, getter: (data) => data.type),
      NUIDBField<NUIErrorLog>(name: "platform", type: NUIEntType.STRING, setter: (data, value) => data.platform = value, getter: (data) => data.platform),
      NUIDBField<NUIErrorLog>(name: "model", type: NUIEntType.STRING, setter: (data, value) => data.model = value, getter: (data) => data.model),
      NUIDBField<NUIErrorLog>(name: "code", type: NUIEntType.STRING, setter: (data, value) => data.code = value, getter: (data) => data.code),
      NUIDBField<NUIErrorLog>(name: "title", type: NUIEntType.STRING, setter: (data, value) => data.title = value, getter: (data) => data.title),
      NUIDBField<NUIErrorLog>(name: "description", type: NUIEntType.STRING, setter: (data, value) => data.description = value, getter: (data) => data.description),
      NUIDBField<NUIErrorLog>(name: "appVersion", type: NUIEntType.STRING, setter: (data, value) => data.appVersion = value, getter: (data) => data.appVersion),
      NUIDBField<NUIErrorLog>(name: "dateTime", type: NUIEntType.DATE, setter: (data, value) => data.dateTime = asDateTime(value), getter: (data) => data.dateTime),
      NUIDBField<NUIErrorLog>(name: "module", type: NUIEntType.STRING, setter: (data, value) => data.module = value, getter: (data) => data.module),
    ];
  }

  @override
  String entityName() => "NUIErrorLogEntity";

  @override
  NUIErrorLog newInstance() => NUIErrorLog.empty();
}
